@@ -12,8 +12,8 @@
 #endif
 #include "ft2_replayer.h"
 
-#define PROG_VER_STR "2.00"
-#define PROG_VER_DATE "21 November 2025"
+#define PROG_VER_STR "2.01"
+#define PROG_VER_DATE "05 December 2025"
 
 // do NOT change these! It will only mess things up...
 
